@@ -5,8 +5,8 @@
 ;; Author: John Wiegley <jwiegley@gmail.com>
 ;; Created: 24 Aug 2011
 ;; Updated: 16 Mar 2015
-;; Package-Version: 1.3
-;; Package-Revision: v1.3-0-g9f329be87820
+;; Package-Version: 20250823.650
+;; Package-Revision: 79f6936ab4d8
 ;; Package-Requires: ((gntp "0.1") (log4e "0.3.0") (cl-lib "0.5"))
 ;; Keywords: notification emacs message
 ;; X-URL: https://github.com/jwiegley/alert
@@ -135,7 +135,8 @@
 ;;   notifier      - Uses terminal-notifier on OS X, if it is on the PATH
 ;;   osx-notifier  - Native OSX notifier using AppleScript
 ;;   toaster       - Use the toast notification system
-;;   x11 -         - Changes the urgency property of the window in the X Window System
+;;   x11           - Changes the urgency property of the window in the X Window System
+;;   termux        - Use termux-notification from the Termux API
 ;;
 ;; * Defining new styles
 ;;
@@ -252,7 +253,7 @@ This is used by styles external to Emacs that don't understand faces."
 
 (defcustom alert-persist-idle-time 900
   "If idle this many seconds, all alerts become persistent.
-This can be overriden with the Never Persist option (:never-persist)."
+This can be overridden with the Never Persist option (:never-persist)."
   :type 'integer
   :group 'alert)
 
@@ -407,7 +408,7 @@ For user customization, see `alert-user-configuration'.")
   :group 'alert)
 
 (defface alert-trivial-face
-  '((t (:foreground "Dark Purple")))
+  '((t (:foreground "Dark Violet")))
   "Trivial alert face."
   :group 'alert)
 
@@ -634,9 +635,8 @@ fringe gets colored whenever people chat on BitlBee:
                     :notifier #'alert-fringe-notify
                     :remover #'alert-fringe-restore)
 
-
+(copy-face 'mode-line 'alert-saved-mode-line-face)
 (defun alert-mode-line-notify (info)
-  (copy-face 'mode-line 'alert-saved-mode-line-face)
   (set-face-background 'mode-line (cdr (assq (plist-get info :severity)
                                              alert-severity-colors)))
   (set-face-foreground 'mode-line "white"))
@@ -672,17 +672,33 @@ This is found in the Growl Extras: http://growl.info/extras.php."
 
 (defun alert-growl-notify (info)
   (if alert-growl-command
-      (let ((args
-             (list "--appIcon"  "Emacs"
-                   "--name"     "Emacs"
-                   "--title"    (alert-encode-string (plist-get info :title))
-                   "--message"  (alert-encode-string (plist-get info :message))
-                   "--priority" (number-to-string
-                                 (cdr (assq (plist-get info :severity)
-                                            alert-growl-priorities))))))
+      (let* ((title (alert-encode-string (plist-get info :title)))
+             (priority (number-to-string
+                        (cdr (assq (plist-get info :severity)
+                                   alert-growl-priorities))))
+             (args
+              (cl-case system-type
+                (windows-nt (mapcar
+                             (lambda (lst) (apply #'concat lst))
+                             `(
+                               ;; http://www.growlforwindows.com/gfw/help/growlnotify.aspx
+                               ("/i:" ,(file-truename (concat invocation-directory "../share/icons/hicolor/48x48/apps/emacs.png")))
+                               ("/t:" ,title)
+                               ("/p:" ,priority))))
+                (t (list
+                    "--appIcon"  "Emacs"
+                    "--name"     "Emacs"
+                    "--title"    title
+                    "--priority" priority)))))
         (if (and (plist-get info :persistent)
                  (not (plist-get info :never-persist)))
-            (nconc args (list "--sticky")))
+            (cl-case system-type
+              (windows-nt (nconc args (list "/s:true")))
+              (t (nconc args (list "--sticky")))))
+        (let ((message (alert-encode-string (plist-get info :message))))
+          (cl-case system-type
+            (windows-nt (nconc args (list message)))
+            (t (nconc args (list "--message" message)))))
         (apply #'call-process alert-growl-command nil nil nil args))
     (alert-message-notify info)))
 
@@ -733,7 +749,7 @@ strings."
                                     (if urgency
                                         (symbol-name urgency)
                                       "normal")))
-               alert-libnotify-additional-args))
+               (copy-tree alert-libnotify-additional-args)))
              (category (plist-get info :category)))
         (nconc args
                (list "--expire-time"
@@ -804,7 +820,7 @@ strings."
   "Internal store of notification ids returned by the `notifications' backend.
 Used for replacing notifications with the same id.  The key is
 the value of the :id keyword to `alert'.  An id is only stored
-here if there `alert' was called ith an :id keyword and handled
+here if there `alert' was called with an :id keyword and handled
 by the `notifications' style.")
 
 (when (featurep 'notifications)
@@ -816,7 +832,11 @@ by the `notifications' style.")
                                     :timeout (if (plist-get info :persistent) 0 -1)
                                     :replaces-id (gethash (plist-get info :id) alert-notifications-ids)
                                     :urgency (cdr (assq (plist-get info :severity)
-                                                        alert-notifications-priorities)))))
+                                                        alert-notifications-priorities))
+                                    :actions '("default" "Open corresponding buffer")
+                                    :on-action (lambda (id action)
+                                                 (when (string= action "default")
+                                                   (switch-to-buffer (plist-get info :buffer)))))))
       (when (plist-get info :id)
         (puthash (plist-get info :id) id alert-notifications-ids)))
     (alert-message-notify info))
@@ -861,10 +881,18 @@ From https://github.com/julienXX/terminal-notifier."
 (defun alert-osx-notifier-notify (info)
   (apply #'call-process "osascript" nil nil nil "-e"
          (list (format "display notification %S with title %S"
-                       (alert-encode-string (plist-get info :message))
-                       (alert-encode-string (plist-get info :title)))))
+                       (plist-get info :message)
+                       (plist-get info :title))))
   (alert-message-notify info))
 
+(when (fboundp 'do-applescript)
+  ;; Use built-in AppleScript support when possible.
+  (defun alert-osx-notifier-notify (info)
+    (do-applescript (format "display notification %S with title %S"
+                            (plist-get info :message)
+                            (plist-get info :title)))
+    (alert-message-notify info)))
+
 (alert-define-style 'osx-notifier :title "Notify using native OSX notification" :notifier #'alert-osx-notifier-notify)
 
 (defun alert-frame-notify (info)
@@ -960,6 +988,30 @@ This is found at https://github.com/nels-o/toaster."
 (alert-define-style 'toaster :title "Notify using Toaster"
                     :notifier #'alert-toaster-notify)
 
+(defcustom alert-termux-command (executable-find "termux-notification")
+  "Path to the termux-notification command.
+This is found in the termux-api package, and it requires the Termux
+API addon app to be installed."
+  :type 'file
+  :group 'alert)
+
+(defun alert-termux-notify (info)
+  "Send INFO using termux-notification.
+Handles :TITLE and :MESSAGE keywords from the
+INFO plist."
+  (if alert-termux-command
+      (let ((args (nconc
+                   (when (plist-get info :title)
+                     (list "-t" (alert-encode-string (plist-get info :title))))
+                   (list "-c" (alert-encode-string (plist-get info :message))))))
+        (apply #'call-process alert-termux-command nil
+               (list (get-buffer-create " *termux-notification output*") t)
+               nil args))
+    (alert-message-notify info)))
+
+(alert-define-style 'termux :title "Notify using termux"
+                    :notifier #'alert-termux-notify)
+
 ;; jww (2011-08-25): Not quite working yet
 ;;(alert-define-style 'frame :title "Popup buffer in a frame"
 ;;                    :notifier #'alert-frame-notify
@@ -1024,19 +1076,21 @@ MESSAGE is what the user will see.  You may also use keyword
 arguments to specify additional details.  Here is a full example:
 
 \(alert \"This is a message\"
-       :severity \\='high          ;; The default severity is `normal'
-       :title \"Title\"           ;; An optional title
-       :category \\='example       ;; A symbol to identify the message
-       :mode \\='text-mode         ;; Normally determined automatically
-       :buffer (current-buffer) ;; This is the default
-       :data nil                ;; Unused by alert.el itself
-       :persistent nil          ;; Force the alert to be persistent;
-                                ;; it is best not to use this
-       :never-persist nil       ;; Force this alert to never persist
-       :id \\='my-id)              ;; Used to replace previous message of
-                                ;; the same id in styles that support it
-       :style \\='fringe)          ;; Force a given style to be used;
-                                ;; this is only for debugging!
+       :severity \\='high            ;; The default severity is `normal'
+       :title \"Title\"              ;; An optional title
+       :category \\='example         ;; A symbol to identify the message
+       :mode \\='text-mode           ;; Normally determined automatically
+       :buffer (current-buffer)      ;; This is the default
+       :data nil                     ;; Unused by alert.el itself
+       :persistent nil               ;; Force the alert to be persistent;
+                                     ;; it is best not to use this
+       :never-persist nil            ;; Force this alert to never persist
+       :id \\='my-id)                ;; Used to replace previous message of
+                                     ;; the same id in styles that support it
+       :style \\='fringe)            ;; Force a given style to be used;
+                                     ;; this is only for debugging!
+       :icon \\=\"mail-message-new\" ;; if style supports icon then add icon
+                                     ;; name or path here
 
 If no :title is given, the buffer-name of :buffer is used.  If
 :buffer is nil, it is the current buffer at the point of call.
@@ -1078,9 +1132,11 @@ Here are some more typical examples of usage:
                            :severity severity
                            :category category
                            :buffer alert-buffer
+                           :persistent persistent
                            :mode current-major-mode
                            :id id
-                           :data data))
+                           :data data
+                           :persistent persistent))
           matched)
 
       (if alert-log-messages
@@ -1088,8 +1144,9 @@ Here are some more typical examples of usage:
 
       (unless alert-hide-all-notifications
         (catch 'finish
-          (dolist (config (append alert-user-configuration
-                                  alert-internal-configuration))
+          (dolist (config (or (append alert-user-configuration
+                                      alert-internal-configuration)
+                              (when style '(nil))))
             (let* ((style-def (cdr (assq (or style (nth 1 config))
                                          alert-styles)))
                    (options (nth 2 config))
